# PyMediaTracker

Asynchronous python client for MediaTracker.
This package allows you to interact with MediaTracker API

## Installation

```bash
pip install pymediatracker
```

## Attributions
- [@timmo001](https://github.com/timmo001) for source of inspiration with his [aiolyric package](https://github.com/timmo001/aiolyric).
- [@ludeeus](https://github.com/ludeeus) for his generator class.

#

⭐️ this repository if you found it useful ❤️

<a href="https://www.buymeacoffee.com/jonkristian" target="_blank"><img src="https://bmc-cdn.nyc3.digitaloceanspaces.com/BMC-button-images/custom_images/white_img.png" alt="Buy Me A Coffee" style="height: auto !important;width: auto !important;" ></a>
